==> inspektr-audit-1.8.2.GA-sources.jar: org/apereo/inspektr/audit/AuditTrailManager.java <==
/**
 * Licensed to Apereo under one or more contributor license
 * agreements. See the NOTICE file distributed with this work
 * for additional information regarding copyright ownership.
 * Apereo licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file
 * except in compliance with the License.  You may obtain a
 * copy of the License at the following location:
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apereo.inspektr.audit;

import java.time.LocalDate;
import java.util.Set;

/**
 * An interface used to make an audit trail record.
 *
 * @author Dmitriy Kopylenko
 * @version $Id : AuditTrailManager.java,v 1.1 2007/06/08 20:43:41 dkopylen Exp $
 * @since 1.0
 */
public interface AuditTrailManager {

    /**
     * Make an audit trail record. Implementations could use any type of back end medium to serialize audit trail
     * data i.e. RDBMS, log file, IO stream, SMTP, JMS queue or what ever else imaginable.
     * <p>
     * This concept is somewhat similar to log4j Appender.
     *
     * @param auditActionContext the audit action context
     */
    void record(AuditActionContext auditActionContext);

    /**
     * Gets audit records since.
     *
     * @param sinceDate the since date
     * @return the audit records since
     */
    Set<AuditActionContext> getAuditRecordsSince(LocalDate sinceDate);
}

==> inspektr-audit-1.8.4.GA-sources.jar: org/apereo/inspektr/audit/AuditTrailManager.java <==
/**
 * Licensed to Apereo under one or more contributor license
 * agreements. See the NOTICE file distributed with this work
 * for additional information regarding copyright ownership.
 * Apereo licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file
 * except in compliance with the License.  You may obtain a
 * copy of the License at the following location:
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apereo.inspektr.audit;

import java.time.LocalDate;
import java.util.Set;

/**
 * An interface used to make an audit trail record.
 *
 * @author Dmitriy Kopylenko
 * @version $Id : AuditTrailManager.java,v 1.1 2007/06/08 20:43:41 dkopylen Exp $
 * @since 1.0
 */
public interface AuditTrailManager {

    /**
     * Make an audit trail record. Implementations could use any type of back end medium to serialize audit trail
     * data i.e. RDBMS, log file, IO stream, SMTP, JMS queue or what ever else imaginable.
     * <p>
     * This concept is somewhat similar to log4j Appender.
     *
     * @param auditActionContext the audit action context
     */
    void record(AuditActionContext auditActionContext);

    /**
     * Gets audit records since.
     *
     * @param sinceDate the since date
     * @return the audit records since
     */
    Set<? extends AuditActionContext> getAuditRecordsSince(LocalDate sinceDate);
}
